<?php

declare(strict_types=1);

namespace Drupal\Tests\static_setting_contexts\Kernel;

use Drupal\Core\Form\FormState;
use Drupal\KernelTests\KernelTestBase;
use Drupal\static_setting_contexts\Plugin\Condition\StaticSettings;
use Drupal\static_setting_contexts_tests\Plugin\StaticSettings\StaticSettingsTestEnum;

/**
 * Tests the StaticSettingsTestEnum as a plugin.
 *
 * @group static_setting_contexts
 */
class StaticSettingsKernelTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'static_setting_contexts',
    'static_setting_contexts_tests',
  ];

  /**
   * Test that the StaticSettingsTestEnum is recognized as a plugin.
   */
  public function testStaticSettingsEnumRecognition(): void {
    // Get the plugin manager service.
    $pluginManager = \Drupal::service('plugin.manager.static_setting_contexts');

    // Get the definitions from the plugin manager.
    $definitions = $pluginManager->getDefinitions();

    // Assert that the plugin manager recognizes the enum.
    $this->assertArrayHasKey('test_setting', $definitions);
    $this->assertEquals(StaticSettingsTestEnum::class, $definitions['test_setting']['class']);
  }

  /**
   * Test StaticSettings condition form shows StaticSettingsTestEnum options.
   */
  public function testStaticSettingsConditionFormOptions(): void {
    // Create a mock form state.
    $form_state = new FormState();

    // Simulate the form building process.
    $form = [];
    $plugin_manager = \Drupal::service('plugin.manager.static_setting_contexts');

    // Create an instance of the StaticSettings condition.
    $static_settings_condition = new StaticSettings([], 'static_setting_contexts_static_settings', [], $plugin_manager);

    // Build the configuration form using the existing method.
    $form = $static_settings_condition->buildConfigurationForm([], $form_state);

    // Assert that the form contains the expected options.
    $this->assertArrayHasKey('static_settings', $form);
    $this->assertArrayHasKey('test_setting', $form['static_settings']);
    $this->assertArrayHasKey('OptionOne', $form['static_settings']['test_setting']['#options']);
    $this->assertArrayHasKey('OptionTwo', $form['static_settings']['test_setting']['#options']);
    $this->assertEquals('Option_one', $form['static_settings']['test_setting']['#options']['OptionOne']);
    $this->assertEquals('Option_two', $form['static_settings']['test_setting']['#options']['OptionTwo']);
  }

}
